@@ -36,7 +36,7 @@ class GlobalOptions(conf_base.Options):
                 help='In case of execution as a service, specifies if the '
                      'service must be gracefully stopped before exiting'),
             cfg.BoolOpt(
-                'check_latest_version', default=True,
+                'check_latest_version', default=False,
                 help='Check if there is a newer version of cloudbase-init '
                      'available.  If this option is activated, a log '
                      'message  will be  emitted if there is a newer version '
@@ -271,6 +271,30 @@ class GlobalOptions(conf_base.Options):
                 'enable_automatic_updates', default=None,
                 help='If set, enables or disables automatic operating '
                      'system updates.'),
+            cfg.BoolOpt(
+                'metadata_report_provisioning_started', default=False,
+                help='Reports to the metadata service that provisioning has '
+                     'started'),
+            cfg.BoolOpt(
+                'metadata_report_provisioning_completed', default=False,
+                help='Reports to the metadata service that provisioning '
+                     'completed successfully or failed'),
+            cfg.StrOpt(
+                'ephemeral_disk_volume_label', default=None,
+                help='Ephemeral disk volume label, e.g.: "Temporary Storage"'),
+            cfg.StrOpt(
+                'ephemeral_disk_volume_mount_point', default=None,
+                help='Ephemeral disk volume mount point, e.g.:'
+                     '"\\\\?\\GLOBALROOT\\device\\Harddisk1\\Partition1\\"'),
+            cfg.StrOpt(
+                'ephemeral_disk_data_loss_warning_path', default=None,
+                help='Ephemeral disk data loss warning path, relative to the '
+                     'ephemeral disk volume path. E.g.: '
+                     'DATALOSS_WARNING_README.txt'),
+            cfg.IntOpt(
+                'user_password_length', default=20,
+                help='The length of the generated password for the user '
+                     'defined by the `username` config option.'),
         ]
 
         self._cli_options = [
