@@ -32,7 +32,6 @@ from cloudbaseinit.utils.windows import vfat
 CONF = cloudbaseinit_conf.CONF
 LOG = oslo_logging.getLogger(__name__)
 
-CONFIG_DRIVE_LABEL = 'config-2'
 MAX_SECTOR_SIZE = 4096
 # Absolute offset values and the ISO magic string.
 OFFSET_BOOT_RECORD = 0x8000
@@ -50,18 +49,25 @@ class WindowsConfigDriveManager(base.BaseConfigDriveManager):
         super(WindowsConfigDriveManager, self).__init__()
         self._osutils = osutils_factory.get_os_utils()
 
-    def _check_for_config_drive(self, drive):
+    def _meta_data_file_exists(self, drive, metadata_file):
+        metadata_file = os.path.join(drive, metadata_file)
+
+        if os.path.exists(metadata_file):
+            return True
+
+        LOG.debug('%s not found', metadata_file)
+        return False
+
+    def _check_for_config_drive(self, drive, required_drive_label,
+                                metadata_file):
         label = self._osutils.get_volume_label(drive)
-        if label and label.lower() == CONFIG_DRIVE_LABEL:
-            if os.path.exists(os.path.join(drive,
-                              'openstack\\latest\\meta_data.json')):
-                LOG.info('Config Drive found on %s', drive)
-                return True
-            LOG.debug('%s\openstack\latest\meta_data.json not '
-                      'found', drive)
+        if label and label.lower() == required_drive_label and \
+                self._meta_data_file_exists(drive, metadata_file):
+            LOG.info('Config Drive found on %s', drive)
+            return True
         LOG.debug("Looking for a Config Drive with label '%s' on '%s'. "
                   "Found mismatching label '%s'.",
-                  CONFIG_DRIVE_LABEL, drive, label)
+                  required_drive_label, drive, label)
         return False
 
     def _get_iso_file_size(self, device):
@@ -137,20 +143,21 @@ class WindowsConfigDriveManager(base.BaseConfigDriveManager):
             os.remove(iso_file_path)
         return extracted
 
-    def _get_config_drive_from_cdrom_drive(self):
+    def _get_config_drive_from_cdrom_drive(self, drive_label, metadata_file):
         for drive_letter in self._osutils.get_cdrom_drives():
-            if self._check_for_config_drive(drive_letter):
+            if self._check_for_config_drive(drive_letter, drive_label,
+                                            metadata_file):
                 os.rmdir(self.target_path)
                 shutil.copytree(drive_letter, self.target_path)
                 return True
 
         return False
 
-    def _get_config_drive_from_raw_hdd(self):
+    def _get_config_drive_from_raw_hdd(self, drive_label, metadata_file):
         disks = map(disk.Disk, self._osutils.get_physical_disks())
         return self._extract_iso_from_devices(disks)
 
-    def _get_config_drive_from_vfat(self):
+    def _get_config_drive_from_vfat(self, drive_label, metadata_file):
         for drive_path in self._osutils.get_physical_disks():
             if vfat.is_vfat_drive(self._osutils, drive_path):
                 LOG.info('Config Drive found on disk %r', drive_path)
@@ -159,7 +166,7 @@ class WindowsConfigDriveManager(base.BaseConfigDriveManager):
                 return True
         return False
 
-    def _get_config_drive_from_partition(self):
+    def _get_config_drive_from_partition(self, drive_label, metadata_file):
         for disk_path in self._osutils.get_physical_disks():
             physical_drive = disk.Disk(disk_path)
             with physical_drive:
@@ -169,22 +176,24 @@ class WindowsConfigDriveManager(base.BaseConfigDriveManager):
                 return True
         return False
 
-    def _get_config_drive_from_volume(self):
+    def _get_config_drive_from_volume(self, drive_label, metadata_file):
         """Look through all the volumes for config drive."""
         volumes = self._osutils.get_volumes()
         for volume in volumes:
-            if self._check_for_config_drive(volume):
+            if self._check_for_config_drive(volume, drive_label,
+                                            metadata_file):
                 os.rmdir(self.target_path)
                 shutil.copytree(volume, self.target_path)
                 return True
         return False
 
-    def _get_config_drive_files(self, cd_type, cd_location):
+    def _get_config_drive_files(self, drive_label, metadata_file,
+                                cd_type, cd_location):
         try:
             get_config_drive = self.config_drive_type_location.get(
                 "{}_{}".format(cd_location, cd_type))
             if get_config_drive:
-                return get_config_drive()
+                return get_config_drive(drive_label, metadata_file)
             else:
                 LOG.debug("Irrelevant type %(type)s in %(location)s "
                           "location; skip",
@@ -196,16 +205,19 @@ class WindowsConfigDriveManager(base.BaseConfigDriveManager):
 
         return False
 
-    def get_config_drive_files(self, searched_types=None,
-                               searched_locations=None):
+    def get_config_drive_files(self, drive_label, metadata_file,
+                               searched_types=None, searched_locations=None):
         searched_types = searched_types or []
         searched_locations = searched_locations or []
 
         for cd_type, cd_location in itertools.product(searched_types,
                                                       searched_locations):
-            LOG.debug('Looking for Config Drive %(type)s in %(location)s',
-                      {"type": cd_type, "location": cd_location})
-            if self._get_config_drive_files(cd_type, cd_location):
+            LOG.debug('Looking for Config Drive %(type)s in %(location)s '
+                      'with expected label %(drive_label)s',
+                      {"type": cd_type, "location": cd_location,
+                       "drive_label": drive_label})
+            if self._get_config_drive_files(drive_label, metadata_file,
+                                            cd_type, cd_location):
                 return True
 
         return False
