@@ -57,6 +57,10 @@ class BaseOSUtils(object):
     def rename_user(self, username, new_username):
         raise NotImplementedError()
 
+    def set_user_info(self, username, full_name=None,
+                      disabled=False, expire_interval=None):
+        raise NotImplementedError()
+
     def enum_users(self):
         raise NotImplementedError()
 
@@ -69,6 +73,12 @@ class BaseOSUtils(object):
     def add_user_to_local_group(self, username, groupname):
         raise NotImplementedError()
 
+    def group_exists(self, group):
+        raise NotImplementedError()
+
+    def create_group(self, group, description=None):
+        raise NotImplementedError()
+
     def set_host_name(self, new_host_name):
         raise NotImplementedError()
 
@@ -78,8 +88,28 @@ class BaseOSUtils(object):
     def get_network_adapters(self):
         raise NotImplementedError()
 
-    def set_static_network_config(self, mac_address, address, netmask,
-                                  broadcast, gateway, dnsnameservers):
+    def get_network_adapter_name_by_mac_address(self, mac_address):
+        raise NotImplementedError()
+
+    def set_network_adapter_mtu(self, name, mtu):
+        raise NotImplementedError()
+
+    def rename_network_adapter(self, old_name, new_name):
+        raise NotImplementedError()
+
+    def enable_network_adapter(self, name, enabled):
+        raise NotImplementedError()
+
+    def set_static_network_config(self, name, address, prefix_len_or_netmask,
+                                  gateway, dnsnameservers):
+        raise NotImplementedError()
+
+    def create_network_team(self, team_name, mode, load_balancing_algorithm,
+                            members, mac_address, primary_nic_name=None,
+                            primary_nic_vlan_id=None, lacp_timer=None):
+        raise NotImplementedError()
+
+    def add_network_team_nic(self, team_name, nic_name, vlan_id):
         raise NotImplementedError()
 
     def set_config_value(self, name, value, section=None):
@@ -181,8 +211,18 @@ class BaseOSUtils(object):
         """Enables or disables TRIM delete notifications."""
         raise NotImplementedError()
 
+    def get_file_version(self, path):
+        raise NotImplementedError()
+
     def set_path_admin_acls(self, path):
         raise NotImplementedError()
 
     def take_path_ownership(self, path, username=None):
         raise NotImplementedError()
+
+    def get_default_script_exec_header(self):
+        """File header where the cloud-config runcmd will be aggregated.
+
+           Example: `#!/bin/bash` for bash or `rem cmd` for cmd.
+        """
+        raise NotImplementedError()
