@@ -36,11 +36,6 @@ class SetUserPasswordPlugin(base.BasePlugin):
             enc_password = rsa.public_encrypt(password.encode())
         return base64.b64encode(enc_password)
 
-    def _get_ssh_public_key(self, service):
-        public_keys = service.get_public_keys()
-        if public_keys:
-            return list(public_keys)[0]
-
     def _get_password(self, service, shared_data):
         injected = False
         if CONF.inject_user_password:
@@ -63,10 +58,10 @@ class SetUserPasswordPlugin(base.BasePlugin):
                       'and it cannot be updated in the instance metadata')
             return True
         else:
-            ssh_pub_key = self._get_ssh_public_key(service)
-            if ssh_pub_key:
-                enc_password_b64 = self._encrypt_password(ssh_pub_key,
-                                                          password)
+            user_pwd_encryption_key = service.get_user_pwd_encryption_key()
+            if user_pwd_encryption_key:
+                enc_password_b64 = self._encrypt_password(
+                    user_pwd_encryption_key, password)
                 return service.post_password(enc_password_b64)
             else:
                 LOG.info('No SSH public key available for password encryption')
@@ -90,9 +85,8 @@ class SetUserPasswordPlugin(base.BasePlugin):
         password, injected = self._get_password(service, shared_data)
         if not password:
             LOG.debug('Generating a random user password')
-            maximum_length = osutils.get_maximum_password_length()
             password = osutils.generate_random_password(
-                maximum_length)
+                CONF.user_password_length)
 
         osutils.set_user_password(user_name, password)
         self._change_logon_behaviour(user_name, password_injected=injected)
