@@ -18,7 +18,7 @@ import re
 from oslo_log import log as oslo_logging
 import six
 
-from cloudbaseinit.metadata.services import base as service_base
+from cloudbaseinit.models import network as network_model
 
 
 LOG = oslo_logging.getLogger(__name__)
@@ -60,7 +60,9 @@ IFACE_TEMPLATE = dict.fromkeys(FIELDS.keys())
 V6_PROXY = {
     ADDRESS: ADDRESS6,
     NETMASK: NETMASK6,
-    GATEWAY: GATEWAY6
+    GATEWAY: GATEWAY6,
+    NAME: NAME,
+    MAC: MAC,
 }
 DETAIL_PREPROCESS = {
     MAC: lambda value: value.upper(),
@@ -79,7 +81,6 @@ def _get_iface_blocks(data):
         if "iface" in line:
             if "inet6" in line:
                 crt_lines = lines6
-                continue
             if lines:
                 yield lines, lines6
             lines[:] = []
@@ -102,7 +103,7 @@ def _add_nic(iface, nics):
         return    # no information gathered
     LOG.debug("Found new interface: %s", iface)
     # Each missing detail is marked as None.
-    nic = service_base.NetworkDetails(**iface)
+    nic = network_model.NetworkDetails(**iface)
     nics.append(nic)
 
 
