@@ -21,6 +21,7 @@ import time
 
 from oslo_log import log as oslo_logging
 
+from cloudbaseinit.utils import network
 
 _DHCP_COOKIE = b'\x63\x82\x53\x63'
 _OPTION_END = b'\xff'
@@ -56,20 +57,20 @@ def _get_dhcp_request_data(id_req, mac_address, requested_options,
 
     if vendor_id:
         vendor_id_b = vendor_id.encode('ascii')
-        data += b'\x3c' + struct.pack('b', len(vendor_id_b)) + vendor_id_b
+        data += b'\x3c' + struct.pack('B', len(vendor_id_b)) + vendor_id_b
 
     data += b'\x3d\x07\x01' + mac_address_b
-    data += b'\x37' + struct.pack('b', len(requested_options))
+    data += b'\x37' + struct.pack('B', len(requested_options))
 
     for option in requested_options:
-        data += struct.pack('b', option)
+        data += struct.pack('B', option)
 
     data += _OPTION_END
     return data
 
 
 def _parse_dhcp_reply(data, id_req):
-    message_type = struct.unpack('b', data[0:1])[0]
+    message_type = struct.unpack('B', data[0:1])[0]
 
     if message_type != 2:
         return False, {}
@@ -86,8 +87,8 @@ def _parse_dhcp_reply(data, id_req):
     i = 240
     data_len = len(data)
     while i < data_len and data[i:i + 1] != _OPTION_END:
-        id_option = struct.unpack('b', data[i:i + 1])[0]
-        option_data_len = struct.unpack('b', data[i + 1:i + 2])[0]
+        id_option = struct.unpack('B', data[i:i + 1])[0]
+        option_data_len = struct.unpack('B', data[i + 1:i + 2])[0]
         i += 2
         options[id_option] = data[i: i + option_data_len]
         i += option_data_len
@@ -98,7 +99,7 @@ def _parse_dhcp_reply(data, id_req):
 def _get_mac_address_by_local_ip(ip_addr):
     for iface in netifaces.interfaces():
         addrs = netifaces.ifaddresses(iface)
-        for addr in addrs[netifaces.AF_INET]:
+        for addr in addrs.get(netifaces.AF_INET, []):
             if addr['addr'] == ip_addr:
                 return addrs[netifaces.AF_LINK][0]['addr']
 
@@ -120,7 +121,7 @@ def _bind_dhcp_client_socket(s, max_bind_attempts, bind_retry_interval):
             time.sleep(bind_retry_interval)
 
 
-def get_dhcp_options(dhcp_host, requested_options=[], timeout=5.0,
+def get_dhcp_options(dhcp_host=None, requested_options=[], timeout=5.0,
                      vendor_id='cloudbase-init', max_bind_attempts=10,
                      bind_retry_interval=3):
     id_req = random.randint(0, 2 ** 32 - 1)
@@ -128,18 +129,21 @@ def get_dhcp_options(dhcp_host, requested_options=[], timeout=5.0,
 
     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+    if not dhcp_host:
+        s.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
+
     try:
         _bind_dhcp_client_socket(s, max_bind_attempts, bind_retry_interval)
 
         s.settimeout(timeout)
-        s.connect((dhcp_host, 67))
 
-        local_ip_addr = s.getsockname()[0]
+        local_ip_addr = network.get_local_ip(dhcp_host)
         mac_address = _get_mac_address_by_local_ip(local_ip_addr)
 
         data = _get_dhcp_request_data(id_req, mac_address, requested_options,
                                       vendor_id)
-        s.send(data)
+
+        s.sendto(data, (dhcp_host or "<broadcast>", 67))
 
         start = datetime.datetime.now()
         now = start
